==> manydhcp2.5.2.tar.bz2: manydhcp/servers/addform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  if(!isset($title)) $title = $TEXT['srv-title-add'];
  if(!isset($button)) $button = $TEXT['btn_add'];
  if(!isset($action)) $action = "add.php";

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['srv-name']; ?>*</td><td><input size=50 maxlength=255 type=text name=name ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-descr']; ?></td><td><input size=50 maxlength=255 type=text name=descr ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-def-lease']; ?>*</td><td><input size=50 maxlength=25 type=text name=def_lease ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-max-lease']; ?>*</td><td><input size=50 maxlength=25 type=text name=max_lease ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ddns-upd']; ?></td><td>
 <select name=ddns_upd_style>
   <option value='none' >none
   <option value='ad-hoc' >ad-hoc
   <option value='interim'>interim
 </select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-log-facility']; ?></td><td><input size=50 maxlength=255 type=text name=log_facility ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-options']; ?>*</td><td><textarea cols=48 rows=5 name=opt_ons ></textarea></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-net']; ?>*</td><td><textarea cols=48 rows=5 name=subnts ></textarea></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ssh']; ?>*</td><td><input size="5" maxlength=5 type=text name=sshport ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-shablon']; ?></td><td><input size="15" maxlength=15 type=text name=shablon ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-autorize']; ?></td><td><input type=checkbox name=autorit ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-vkl']; ?></td><td><input type=checkbox name=vkl ></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ping']; ?></td><td>
 <select name=ping_ok>
   <option value='yes' selected ><?php echo $TEXT['addr-vkluchit2']; ?>
   <option value='no' ><?php echo $TEXT['addr-vikluchit2']; ?>
 </select>
</td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/servers/addform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['srv-title-add'];
  $button = $TEXT['btn_add'];
  $action = "add.php";

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['srv-name']; ?>*</td><td><input size=50 maxlength=255 type=text name=name ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-descr']; ?></td><td><input size=50 maxlength=255 type=text name=descr ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-def-lease']; ?>*</td><td><input size=50 maxlength=25 type=text name=def_lease ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-max-lease']; ?>*</td><td><input size=50 maxlength=25 type=text name=max_lease ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ddns-upd']; ?></td><td>
 <select name=ddns_upd_style>
   <option value='none' >none
   <option value='ad-hoc' >ad-hoc
   <option value='interim'>interim
 </select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-log-facility']; ?></td><td><input size=50 maxlength=255 type=text name=log_facility ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-options']; ?>*</td><td><textarea cols=48 rows=5 name=opt_ons ></textarea></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-net']; ?>*</td><td><textarea cols=48 rows=5 name=subnts ></textarea></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ssh']; ?>*</td><td><input size="5" maxlength=5 type=text name=sshport ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-shablon']; ?></td><td><input size="15" maxlength=15 type=text name=shablon ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-autorize']; ?></td><td><input type=checkbox name=autorit ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-vkl']; ?></td><td><input type=checkbox name=vkl ></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['srv-ping']; ?></td><td>
 <select name=ping_ok>
   <option value='yes' selected ><?php echo $TEXT['addr-vkluchit2']; ?>
   <option value='no' ><?php echo $TEXT['addr-vikluchit2']; ?>
 </select>
</td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
